==> haskell-wai-extra-3.0.24.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.24.2
id: wai-extra-3.0.24.2-IgMDEhmvI6CGwifiosyX99
key: wai-extra-3.0.24.2-IgMDEhmvI6CGwifiosyX99
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
abi: 606883fd7d1ac4c312f2d5b876727a54
exposed: True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-extra-3.0.24.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-extra-3.0.24.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-extra-3.0.24.2
hs-libraries: HSwai-extra-3.0.24.2-IgMDEhmvI6CGwifiosyX99
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh time-1.8.0.2
    network-2.7.0.2-1OJnZsn219R1IXngT025LR directory-1.3.1.5
    transformers-0.5.5.0 http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
    text-1.2.3.0 case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    wai-logger-2.3.2-DvzaR4Ud4LUCduc5n837Et
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
    stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq containers-0.5.11.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
    lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu deepseq-1.4.3.0
    streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I
    unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    vault-0.3.1.2-5B8S6rFwr1D8MB8kwwCb82
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
    aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX
    iproute-1.7.5-3gvixGtUYR74aBofh34bnE unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf=91ba5164ada377f7d55099a2359e2c5a
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=a68d513cb967eb5123e3b68a7f96a4a8
             wai-logger-2.3.2-DvzaR4Ud4LUCduc5n837Et=6934384c486275358e2faf9afc6aa351
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I=3fbb0f35b28cf76949df3af0a83627ff
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
             stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq=ed935341c730497ba619c3fc7dd58923
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=17353ed56fb5c760af7bb1df1e6d2f4c
             lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu=c1af0fff2fd5bc4c8d013de762962125
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I=d02eb8f4075c36aa63e714831eccd502
             unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj=2a0e42b97373c43e88dbd8b7b82c7192
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=98943a44942d0f9eb24e49aaa7774a37
             vault-0.3.1.2-5B8S6rFwr1D8MB8kwwCb82=f48f34e99d4eca1a996c7cd27e643185
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=8fa648805d93281f19b98bbf203b4b1c
             aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX=703c560734a72c2a014a198df0039e3a
             iproute-1.7.5-3gvixGtUYR74aBofh34bnE=9c06c1d584a99fbc7bac0386f5bf37ec
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.24.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.24.2
id: wai-extra-3.0.24.2-HpgYlPszNoFLxpcXb2168R
key: wai-extra-3.0.24.2-HpgYlPszNoFLxpcXb2168R
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
abi: e53d9f739e200fca54f17d5c9406f9c3
exposed: True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-extra-3.0.24.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-extra-3.0.24.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-extra-3.0.24.2
hs-libraries: HSwai-extra-3.0.24.2-HpgYlPszNoFLxpcXb2168R
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh time-1.8.0.2
    network-2.7.0.2-1OJnZsn219R1IXngT025LR directory-1.3.1.5
    transformers-0.5.5.0 http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
    text-1.2.3.0 case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    wai-logger-2.3.2-DvzaR4Ud4LUCduc5n837Et
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    resourcet-1.2.1-4yIj5vhBKtUFmGmRscYOk4
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
    stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq containers-0.5.11.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
    lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu deepseq-1.4.3.0
    streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I
    unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    vault-0.3.1.2-5B8S6rFwr1D8MB8kwwCb82
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
    aeson-1.4.0.0-9qWiRNFZVktJndCRfB1Mai
    iproute-1.7.5-3gvixGtUYR74aBofh34bnE unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf=91ba5164ada377f7d55099a2359e2c5a
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=a68d513cb967eb5123e3b68a7f96a4a8
             wai-logger-2.3.2-DvzaR4Ud4LUCduc5n837Et=6934384c486275358e2faf9afc6aa351
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             resourcet-1.2.1-4yIj5vhBKtUFmGmRscYOk4=e827df729ce0f86597c362a6f5dd6126
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
             stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq=ed935341c730497ba619c3fc7dd58923
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=17353ed56fb5c760af7bb1df1e6d2f4c
             lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu=c1af0fff2fd5bc4c8d013de762962125
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I=d02eb8f4075c36aa63e714831eccd502
             unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj=2a0e42b97373c43e88dbd8b7b82c7192
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=98943a44942d0f9eb24e49aaa7774a37
             vault-0.3.1.2-5B8S6rFwr1D8MB8kwwCb82=f48f34e99d4eca1a996c7cd27e643185
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=8fa648805d93281f19b98bbf203b4b1c
             aeson-1.4.0.0-9qWiRNFZVktJndCRfB1Mai=107057a2dbf5fda7f784a80ae20f44b9
             iproute-1.7.5-3gvixGtUYR74aBofh34bnE=9c06c1d584a99fbc7bac0386f5bf37ec
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
